<?php

return [
    /*
     * 法律合规 - 居民个人信息保护
     *
     * 依据《个人信息保护法》：
     * - 第六条：收集个人信息应限于实现处理目的的最小范围
     * - 第十九条：个人信息的保存期限应为实现目的所必需的最短时间
     * - 第二十八条：敏感个人信息（身份证号、人脸、住址）需单独授权
     * - 第五十一条：采取加密等安全措施保护个人信息
     */
    'privacy' => [
        'encrypt_fields' => true,                                      // 对敏感字段加密
        'encrypted_fields' => ['id_card', 'phone', 'bank_account'],    // 需加密的字段
        'data_retention_months' => 24,                                 // 数据保留期限（月）
        'consent_required' => true,                                    // 收集前需用户同意
        'anonymize_on_delete' => true,                                 // 删除时匿名化处理
    ],

    // 社区服务配置
    'service_categories' => [
        'certificate' => '证明开具',
        'consultation' => '政策咨询',
        'registration' => '登记办理',
        'notarization' => '公证服务',
        'other' => '其他服务',
    ],

    // 特殊群体标签
    'special_groups' => [
        'elderly' => '老年人（60岁以上）',
        'disabled' => '残障人士',
        'low_income' => '低保家庭',
        'living_alone' => '独居老人',
    ],

    // 报修类别
    'repair_categories' => [
        'plumbing' => '水管',
        'electrical' => '电路',
        'door_window' => '门窗',
        'elevator' => '电梯',
        'public_facility' => '公共设施',
        'greening' => '绿化',
        'other' => '其他',
    ],

    // 活动类型
    'activity_types' => [
        'sports' => '文体活动',
        'public_welfare' => '公益活动',
        'lecture' => '知识讲座',
        'training' => '技能培训',
        'festival' => '节日活动',
        'other' => '其他',
    ],

    // 互助类型
    'help_types' => [
        'borrow' => '物品借用',
        'skill' => '技能分享',
        'errand' => '代买代办',
        'companion' => '陪伴出行',
        'other' => '其他',
    ],

    // 投诉类型
    'complaint_types' => [
        'environment' => '环境卫生',
        'noise' => '噪音扰民',
        'parking' => '停车问题',
        'facility' => '设施损坏',
        'safety' => '安全隐患',
        'service' => '服务投诉',
        'other' => '其他',
    ],

    // 缴费类型
    'payment_types' => [
        'property' => '物业费',
        'water' => '水费',
        'electricity' => '电费',
        'gas' => '燃气费',
        'parking' => '停车费',
        'other' => '其他',
    ],
];
