<?php

namespace Kylin\Community\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

/**
 * 互助消息
 */
class HelpMessage extends Model
{
    protected $fillable = [
        'help_id',
        'resident_id',
        'content',
    ];

    public function help(): BelongsTo
    {
        return $this->belongsTo(Help::class);
    }

    public function resident(): BelongsTo
    {
        return $this->belongsTo(Resident::class);
    }
}
